@@ -96,7 +96,7 @@ private:
       auto cell = cells_[i];
       auto format = cell.get().format();
       if (format.width_.has_value())
-        result = std::max(result, format.width_.value());
+        result = std::max(result, *format.width_);
     }
     return result;
   }
@@ -124,7 +124,7 @@ private:
     Cell &cell = cells_[cell_index].get();
     auto format = cell.format();
     if (format.padding_left_.has_value())
-      result += format.padding_left_.value();
+      result += *format.padding_left_;
 
     // Check if input text has newlines
     auto text = cell.get_text();
@@ -148,7 +148,7 @@ private:
     }
 
     if (format.padding_right_.has_value())
-      result += format.padding_right_.value();
+      result += *format.padding_right_;
 
     return result;
   }
