@@ -94,7 +94,7 @@ private:
       auto cell = cells_[i];
       auto format = cell->format();
       if (format.height_.has_value())
-        result = std::max(result, format.height_.value());
+        result = std::max(result, *format.height_);
     }
     return result;
   }
@@ -136,10 +136,10 @@ private:
     auto format = cell.format();
     auto text = cell.get_text();
 
-    auto padding_left = format.padding_left_.value();
-    auto padding_right = format.padding_right_.value();
+    auto padding_left = *format.padding_left_;
+    auto padding_right = *format.padding_right_;
 
-    result += format.padding_top_.value();
+    result += *format.padding_top_;
 
     if (column_width > (padding_left + padding_right)) {
       column_width -= (padding_left + padding_right);
@@ -169,7 +169,7 @@ private:
 
     result += estimated_row_height;
 
-    result += format.padding_bottom_.value();
+    result += *format.padding_bottom_;
 
     return result;
   }
